pub struct FlatOption {
pub dimension: u32,
pub distance: i32,
pub base_weight: f32,
pub quantizer: Option<QuantizationConfig>,
pub embedder: String,
}Fields
dimension: u32distance: i32base_weight: f32quantizer: Option<QuantizationConfig>embedder: StringEmbedder name (empty = no auto-embedding).
Implementations
Sourceimpl FlatOption
impl FlatOption
Sourcepub fn distance(&self) -> DistanceMetric
pub fn distance(&self) -> DistanceMetric
Returns the enum value of distance, or the default if the field is set to an invalid enum value.
Sourcepub fn set_distance(&mut self, value: DistanceMetric)
pub fn set_distance(&mut self, value: DistanceMetric)
Sets distance to the provided enum value.