pub struct QuantizationConfig {
pub method: i32,
pub subvector_count: u32,
}Fields
method: i32subvector_count: u32Only used when method is PRODUCT_QUANTIZATION.
Implementations
Sourceimpl QuantizationConfig
impl QuantizationConfig
Sourcepub fn method(&self) -> QuantizationMethod
pub fn method(&self) -> QuantizationMethod
Returns the enum value of method, or the default if the field is set to an invalid enum value.
Sourcepub fn set_method(&mut self, value: QuantizationMethod)
pub fn set_method(&mut self, value: QuantizationMethod)
Sets method to the provided enum value.