pub enum Kind {
NullValue(bool),
BoolValue(bool),
Int64Value(i64),
Float64Value(f64),
TextValue(String),
BytesValue(Vec<u8>),
VectorValue(VectorValue),
DatetimeValue(i64),
GeoValue(GeoPoint),
}Variants
NullValue(bool)
BoolValue(bool)
Int64Value(i64)
Float64Value(f64)
TextValue(String)
BytesValue(Vec<u8>)
VectorValue(VectorValue)
DatetimeValue(i64)
Unix microseconds (UTC)
GeoValue(GeoPoint)
Implementations
Sourceimpl Kind
impl Kind
Sourcepub fn merge(
field: &mut Option<Kind>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Kind>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.